︠b2279612-1516-485e-b6af-8311569b84f4i︠
%md
Mandelbrot set.  From https://wiki.sagemath.org/interact/fractal
︡d392240a-e442-4fcb-bd23-be7afe28f64b︡{"done":true,"md":"Mandelbrot set.  From https://wiki.sagemath.org/interact/fractal"}
︠d5dd9fb8-0d0e-4967-900a-f02a15fcd158s︠
%auto
%cython
import numpy as np
cimport numpy as np

def mandelbrot_cython(float x0,float  x1,float  y0,float  y1,
                   int N=200, int L=50, float R=3):
    '''returns an array NxN to be plotted with matrix_plot
    '''
    cdef double complex c, z, I
    cdef float deltax, deltay, R2 = R*R
    cdef int h, j, k
    cdef np.ndarray[np.uint16_t, ndim=2] m
    m = np.zeros((N,N), dtype=np.uint16)
    I = complex(0,1)
    deltax = (x1-x0)/N
    deltay = (y1-y0)/N
    for j in range(N):
        for k in range(N):
            c = (x0+j*deltax)+ I*(y0+k*deltay)
            z=0
            h=0
            while (h<L and
                   z.real**2 + z.imag**2 < R2):
                z=z*z+c
                h+=1
            m[j,k]=h
    return m
︡7ea48196-b42e-48b4-85ae-12b943cd101c︡{"stdout":"Defined mandelbrot_cython, np"}︡{"stdout":"\n"}︡{"file":{"filename":"/home/user/.sage/temp/project-4a5f0542-5873-4eed-a85c-a18c706e8bcd/113/spyx/_home_user__sage_temp_project_4a5f0542_5873_4eed_a85c_a18c706e8bcd_113_dir_E9EIOj_a_pyx/_home_user__sage_temp_project_4a5f0542_5873_4eed_a85c_a18c706e8bcd_113_dir_E9EIOj_a_pyx_0.html","show":true,"text":"Auto-generated code...","url":"/4a5f0542-5873-4eed-a85c-a18c706e8bcd/raw/.sage/temp/project-4a5f0542-5873-4eed-a85c-a18c706e8bcd/113/spyx/_home_user__sage_temp_project_4a5f0542_5873_4eed_a85c_a18c706e8bcd_113_dir_E9EIOj_a_pyx/_home_user__sage_temp_project_4a5f0542_5873_4eed_a85c_a18c706e8bcd_113_dir_E9EIOj_a_pyx_0.html"},"once":false}︡{"done":true}︡
︠dcf98d45-5da4-4fbc-a142-42531c82fda7s︠
%auto
import pylab
x0_default = -2
y0_default = -1.5
side_default = 3.0
side = side_default
x0 = x0_default
y0 = y0_default
N = 100
L = 20
︡a56b8643-75cc-4018-a1c0-4e9dea93c6e3︡
︠1aaa05cc-0880-4990-b26f-ede58917d5dbs︠
%time
m=mandelbrot_cython(x0 ,x0 + side ,y0 ,y0 + side , N, L )
pylab.clf()
pylab.imshow(m, cmap = pylab.cm.gray)
︡c6dff1f9-bb37-4c96-92f0-9925c38da1f1︡{"file":{"filename":"/home/user/.sage/temp/project-4a5f0542-5873-4eed-a85c-a18c706e8bcd/113/tmp_Z0a2oq.png","show":true,"text":null,"uuid":"d10ee7f7-dcec-4c39-b210-79c6e38108b9"},"once":false}︡{"stdout":"\nCPU time: 0.06 s, Wall time: 0.07 s\n"}︡{"done":true}︡
︠c3c029a6-d749-4020-a11b-77ee3110afdc︠
options = ['Reset','Upper Left', 'Upper Right', 'Stay', 'Lower Left', 'Lower Right']

@interact
def show_mandelbrot(option = selector(options, nrows = 2, width=8),
                    N = slider(100, 1000,100, 300),
                    L = slider(20, 300, 20, 60),
                    plot_size = slider(2,10,1,6),
                    auto_update = False):
    global x0, y0, side
    if option == 'Lower Right':
        x0 += side/2
        y0 += side/2
    elif option == 'Upper Right':
        y0 += side/2
    elif option == 'Lower Left':
        x0 += side/2
    if option=='Reset':
        side = side_default
        x0 = x0_default
        y0 = y0_default
    elif option != 'Stay':
        side = side/2

    m=mandelbrot_cython(x0 ,x0 + side ,y0 ,y0 + side , N, L )
    pylab.clf()
    pylab.imshow(m, cmap = pylab.cm.gray)
    pylab.show()
︡b5c5898b-586c-48a5-918a-f38e819aebb8︡{"interact":{"controls":[{"button_classes":null,"buttons":false,"control_type":"selector","default":0,"label":"option","lbls":["Reset","Upper Left","Upper Right","Stay","Lower Left","Lower Right"],"ncols":null,"nrows":2,"var":"option","width":8},{"animate":true,"control_type":"slider","default":2,"display_value":true,"label":"N","vals":["100","200","300","400","500","600","700","800","900","1000"],"var":"N","width":null},{"animate":true,"control_type":"slider","default":2,"display_value":true,"label":"L","vals":["20","40","60","80","100","120","140","160","180","200","220","240","260","280","300"],"var":"L","width":null},{"animate":true,"control_type":"slider","default":4,"display_value":true,"label":"plot_size","vals":["2","3","4","5","6","7","8","9","10"],"var":"plot_size","width":null},{"control_type":"checkbox","default":false,"label":"auto_update","readonly":false,"var":"auto_update"}],"flicker":false,"id":"84482cd1-5dc8-454f-89b7-ac87f790d707","layout":[[["option",12,null]],[["N",12,null]],[["L",12,null]],[["plot_size",12,null]],[["auto_update",12,null]],[["",12,null]]],"style":"None"}}︡{"done":true}︡
︠cc61b49f-9d14-4c72-ae43-b2609d06d2ab︠









